Glowing-waffles
===============

What do glowing waffles have to do with astronomy? Absolutely nothing.

Nonetheless, this is a package to do stellar photometry using `astropy`_ and
`astropy affiliated packages`_.

If you have an idea for a better name we are all ears...

.. _astropy: http://astropy.org
.. _astropy affiliated packages: http://www.astropy.org/affiliated/index.html
